#version 150
precision highp float; precision highp int;
//Ethan Alexander Shulman 2023 "The Absolute" October 4, 2023

in vec3 in_Position;
out vec4 uv;
out float time;

layout(std140) uniform ShaderviewBlock {
	vec4 mouse;
	float screenX,screenY;
	int frame,framerate;
};

#define AA_SAMPLES 1
#define ANIMATION 1

#define PI 3.141592653589793


mat2 r2d(float a) {
	float c = cos(a), s = sin(a);
	return mat2(c,s,-s,c);
}
//r2 hash http://extremelearning.com.au/unreasonable-effectiveness-of-quasirandom-sequences/
vec2 quasiRandom(float n) {
	#define R2V 1.32471795724474602596
	return fract(.5+n*(1./vec2(R2V,R2V*R2V)));
}


uniform sampler2D Buffer0;

void vert() {
	#ifdef ANIMATION
	//0-60
	time = float(frame)/float(framerate*AA_SAMPLES)*.1;
	#else
	//screenshot 1
	time = .5;
	
	//screenshot 2
	//time = 1.8;
	#endif
	
	uv = vec4((in_Position.xy*vec2(screenX/screenY,1)+(quasiRandom(float(frame%AA_SAMPLES))-.5)*2./screenY),
		(in_Position.xy*.5+.5)*vec2(screenX,screenY));
	gl_Position = vec4(in_Position,1);
}
void frag() {
	vec2 p = uv.xy;
	p = (p*(1.6))-vec2(0,.2);
	p.x = abs(p.x);
	
	p *= r2d(p.x*.8);
	p.y = -p.y;
	p *= r2d(p.x*.5+(p.y+1.));

		
	float fx = floor(p.x*200.)+time,
		oy = fx*.27643;
	vec3 c = vec3(max(0.,fract(p.y+10.+oy)*4.-3.));

	vec4 sum = texelFetch(Buffer0,ivec2(uv.zw),0);
	if (frame%AA_SAMPLES == 0) sum = vec4(0);
	sum += vec4(c, 1.);
	gl_FragColor = sum;
}
